Crate perplex_runtime[−][src]
A collection of facilities required by perplex-generated parsers.
Structs
| IterInput |
A wrapper for using iterators as parser input. |
| ParserMachine |
A parser state machine. |
Enums
| Symbol |
A symbol on the parse stack. |
Traits
| Parser |
A parser that can be passed to generated states. |
| ParserInput |
An stream of tokens that can be used as parser input. |
| StateSpace |
A description of a parser's state space. |